@@ -60,7 +60,7 @@ sub import {
 }
 
 
-our $VERSION = '0.0245';    # VERSION
+our $VERSION = '0.0246';    # VERSION
 
 1;
 
@@ -78,7 +78,7 @@ Evo - Evo - the next generation development framework
 
 =head1 VERSION
 
-version 0.0245
+version 0.0246
 
 =head1 DESCRIPTION
 
@@ -97,7 +97,7 @@ It provides rewritten and postmodern features like
 [almost ready] Fast non recursive "Promise" role, 100% "Promise/Spec A" compatible. + See L<Mojo::Promise>
 
 =item *
-(almost ready) Exception handling in pure perl: L<Evo::Lib/eval>, like "try catch" but perl way.
+(almost ready) Exception handling in pure perl: L<Evo::Lib/try>, like "try catch" but perl way.
 30 lines of code and much faster (L<https://github.com/alexbyk/perl-evo/tree/master/bench#evolibtry>) than other alternatives
 
 =item *
