@@ -1,7 +1,6 @@
 package Evo::Class::Attrs::XS;
-use Evo 'XSLoader';
+use Evo 'XSLoader; -Export';
 
-use Evo '-Export; Carp croak confess';
 use constant {ECA_SIMPLE => 0, ECA_DEFAULT => 1, ECA_DEFAULT_CODE => 2, ECA_REQUIRED => 3,
   ECA_LAZY => 4,};
 
@@ -9,7 +8,7 @@ export qw(
   ECA_SIMPLE ECA_DEFAULT ECA_DEFAULT_CODE ECA_REQUIRED ECA_LAZY
 );
 
-our $VERSION = '0.0245';    # VERSION
+our $VERSION = '0.0246';    # VERSION
 
 # to be able to run with and without dzil
 my $version = eval '$VERSION';    ## no critic
@@ -19,12 +18,6 @@ $version
 
 sub new { bless [], shift }
 
-sub gen_attr ($self, $name, $type, $value, $check, $ro, $inject) {
-  my $slot_ref = $self->_reg_attr($name, $type, $value, $check, $ro, $inject);
-  $self->_gen_attr($slot_ref);
-}
-
-
 1;
 
 # ABSTRACT: XS implementation of attributes and "new" method generator
@@ -41,7 +34,7 @@ Evo::Class::Attrs::XS - XS implementation of attributes and "new" method generat
 
 =head1 VERSION
 
-version 0.0245
+version 0.0246
 
 =head1 AUTHOR
 
